@@ -1,4 +1,5 @@
-/*
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
+ *
  *    GDMcommunication routines
  *    (c)2001 Queen of England, (c)2002,2003 George Lebl
  *    
@@ -40,6 +41,11 @@
 #include "gdmcommon.h"
 #include "gdmconfig.h"
 
+#include "gdm-common.h"
+#include "gdm-log.h"
+#include "gdm-socket-protocol.h"
+#include "gdm-daemon-config-keys.h"
+
 static char *myname = NULL;  /* name of this program */
 
 static void
@@ -79,7 +85,6 @@ main (int argc, char *argv[])
     int background        = 0;
     gboolean error        = TRUE;
     gboolean conn_failed  = FALSE;
-    gboolean gdm_running;
 
     myname  = basename (argv[0]);
     argv[0] = myname;
@@ -154,7 +159,7 @@ main (int argc, char *argv[])
     }
 
     /* process remaining option arguments for -l */
-    if (command == GDM_SUP_ATTACHED_SERVERS)
+    if (command != NULL && strcmp (command, GDM_SUP_ATTACHED_SERVERS) == 0)
         for (; optind<argc; optind++)
             params = argv[optind];
 
@@ -169,7 +174,9 @@ main (int argc, char *argv[])
         }
     }
 
-    gdmcomm_set_debug (verbose);
+    gdm_log_init ();
+    gdm_log_set_debug (verbose);
+
     /*
      * If verbose is not on, then set quiet errors to TRUE since
      * errors are expected and managed by gdmdynamic, so we want
